@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 import functools
 import re
@@ -22,10 +20,10 @@ from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
 import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.websecurityscanner_v1.services.web_security_scanner import pagers
@@ -38,8 +36,7 @@ from google.cloud.websecurityscanner_v1.types import scan_run
 from google.cloud.websecurityscanner_v1.types import scan_run_error_trace
 from google.cloud.websecurityscanner_v1.types import scan_run_warning_trace
 from google.cloud.websecurityscanner_v1.types import web_security_scanner
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-
+from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import WebSecurityScannerTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import WebSecurityScannerGrpcAsyncIOTransport
 from .client import WebSecurityScannerClient
@@ -59,31 +56,26 @@ class WebSecurityScannerAsyncClient:
 
     finding_path = staticmethod(WebSecurityScannerClient.finding_path)
     parse_finding_path = staticmethod(WebSecurityScannerClient.parse_finding_path)
-
     common_billing_account_path = staticmethod(
         WebSecurityScannerClient.common_billing_account_path
     )
     parse_common_billing_account_path = staticmethod(
         WebSecurityScannerClient.parse_common_billing_account_path
     )
-
     common_folder_path = staticmethod(WebSecurityScannerClient.common_folder_path)
     parse_common_folder_path = staticmethod(
         WebSecurityScannerClient.parse_common_folder_path
     )
-
     common_organization_path = staticmethod(
         WebSecurityScannerClient.common_organization_path
     )
     parse_common_organization_path = staticmethod(
         WebSecurityScannerClient.parse_common_organization_path
     )
-
     common_project_path = staticmethod(WebSecurityScannerClient.common_project_path)
     parse_common_project_path = staticmethod(
         WebSecurityScannerClient.parse_common_project_path
     )
-
     common_location_path = staticmethod(WebSecurityScannerClient.common_location_path)
     parse_common_location_path = staticmethod(
         WebSecurityScannerClient.parse_common_location_path
@@ -91,7 +83,8 @@ class WebSecurityScannerAsyncClient:
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -106,7 +99,7 @@ class WebSecurityScannerAsyncClient:
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -123,7 +116,7 @@ class WebSecurityScannerAsyncClient:
 
     @property
     def transport(self) -> WebSecurityScannerTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
             WebSecurityScannerTransport: The transport used by the client instance.
@@ -138,12 +131,12 @@ class WebSecurityScannerAsyncClient:
     def __init__(
         self,
         *,
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         transport: Union[str, WebSecurityScannerTransport] = "grpc_asyncio",
         client_options: ClientOptions = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the web security scanner client.
+        """Instantiates the web security scanner client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -175,7 +168,6 @@ class WebSecurityScannerAsyncClient:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
-
         self._client = WebSecurityScannerClient(
             credentials=credentials,
             transport=transport,
@@ -197,7 +189,6 @@ class WebSecurityScannerAsyncClient:
             request (:class:`google.cloud.websecurityscanner_v1.types.CreateScanConfigRequest`):
                 The request object. Request for the `CreateScanConfig`
                 method.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -211,7 +202,6 @@ class WebSecurityScannerAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = web_security_scanner.CreateScanConfigRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -249,7 +239,6 @@ class WebSecurityScannerAsyncClient:
             request (:class:`google.cloud.websecurityscanner_v1.types.DeleteScanConfigRequest`):
                 The request object. Request for the `DeleteScanConfig`
                 method.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -257,7 +246,6 @@ class WebSecurityScannerAsyncClient:
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-
         request = web_security_scanner.DeleteScanConfigRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -269,7 +257,8 @@ class WebSecurityScannerAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
                 deadline=600.0,
             ),
@@ -302,7 +291,6 @@ class WebSecurityScannerAsyncClient:
             request (:class:`google.cloud.websecurityscanner_v1.types.GetScanConfigRequest`):
                 The request object. Request for the `GetScanConfig`
                 method.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -316,7 +304,6 @@ class WebSecurityScannerAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = web_security_scanner.GetScanConfigRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -328,7 +315,8 @@ class WebSecurityScannerAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
                 deadline=600.0,
             ),
@@ -362,7 +350,6 @@ class WebSecurityScannerAsyncClient:
             request (:class:`google.cloud.websecurityscanner_v1.types.ListScanConfigsRequest`):
                 The request object. Request for the `ListScanConfigs`
                 method.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -378,7 +365,6 @@ class WebSecurityScannerAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = web_security_scanner.ListScanConfigsRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -390,7 +376,8 @@ class WebSecurityScannerAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
                 deadline=600.0,
             ),
@@ -431,7 +418,6 @@ class WebSecurityScannerAsyncClient:
             request (:class:`google.cloud.websecurityscanner_v1.types.UpdateScanConfigRequest`):
                 The request object. Request for the
                 `UpdateScanConfigRequest` method.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -445,7 +431,6 @@ class WebSecurityScannerAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = web_security_scanner.UpdateScanConfigRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -484,7 +469,6 @@ class WebSecurityScannerAsyncClient:
             request (:class:`google.cloud.websecurityscanner_v1.types.StartScanRunRequest`):
                 The request object. Request for the `StartScanRun`
                 method.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -499,7 +483,6 @@ class WebSecurityScannerAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = web_security_scanner.StartScanRunRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -535,7 +518,6 @@ class WebSecurityScannerAsyncClient:
         Args:
             request (:class:`google.cloud.websecurityscanner_v1.types.GetScanRunRequest`):
                 The request object. Request for the `GetScanRun` method.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -550,7 +532,6 @@ class WebSecurityScannerAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = web_security_scanner.GetScanRunRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -562,7 +543,8 @@ class WebSecurityScannerAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
                 deadline=600.0,
             ),
@@ -597,7 +579,6 @@ class WebSecurityScannerAsyncClient:
             request (:class:`google.cloud.websecurityscanner_v1.types.ListScanRunsRequest`):
                 The request object. Request for the `ListScanRuns`
                 method.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -613,7 +594,6 @@ class WebSecurityScannerAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = web_security_scanner.ListScanRunsRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -625,7 +605,8 @@ class WebSecurityScannerAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
                 deadline=600.0,
             ),
@@ -665,7 +646,6 @@ class WebSecurityScannerAsyncClient:
             request (:class:`google.cloud.websecurityscanner_v1.types.StopScanRunRequest`):
                 The request object. Request for the `StopScanRun`
                 method.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -680,7 +660,6 @@ class WebSecurityScannerAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = web_security_scanner.StopScanRunRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -717,7 +696,6 @@ class WebSecurityScannerAsyncClient:
             request (:class:`google.cloud.websecurityscanner_v1.types.ListCrawledUrlsRequest`):
                 The request object. Request for the `ListCrawledUrls`
                 method.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -733,7 +711,6 @@ class WebSecurityScannerAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = web_security_scanner.ListCrawledUrlsRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -745,7 +722,8 @@ class WebSecurityScannerAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
                 deadline=600.0,
             ),
@@ -784,7 +762,6 @@ class WebSecurityScannerAsyncClient:
         Args:
             request (:class:`google.cloud.websecurityscanner_v1.types.GetFindingRequest`):
                 The request object. Request for the `GetFinding` method.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -799,7 +776,6 @@ class WebSecurityScannerAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = web_security_scanner.GetFindingRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -811,7 +787,8 @@ class WebSecurityScannerAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
                 deadline=600.0,
             ),
@@ -845,7 +822,6 @@ class WebSecurityScannerAsyncClient:
             request (:class:`google.cloud.websecurityscanner_v1.types.ListFindingsRequest`):
                 The request object. Request for the `ListFindings`
                 method.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -861,7 +837,6 @@ class WebSecurityScannerAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = web_security_scanner.ListFindingsRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -873,7 +848,8 @@ class WebSecurityScannerAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
                 deadline=600.0,
             ),
@@ -913,7 +889,6 @@ class WebSecurityScannerAsyncClient:
             request (:class:`google.cloud.websecurityscanner_v1.types.ListFindingTypeStatsRequest`):
                 The request object. Request for the
                 `ListFindingTypeStats` method.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -925,7 +900,6 @@ class WebSecurityScannerAsyncClient:
                 Response for the ListFindingTypeStats method.
         """
         # Create or coerce a protobuf request object.
-
         request = web_security_scanner.ListFindingTypeStatsRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -937,7 +911,8 @@ class WebSecurityScannerAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
                 deadline=600.0,
             ),
