@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
 
@@ -33,7 +31,6 @@ __protobuf__ = proto.module(
 
 class Form(proto.Message):
     r"""! Information about a vulnerability with an HTML.
-
     Attributes:
         action_uri (str):
             ! The URI where to send the form when it's
@@ -43,14 +40,12 @@ class Form(proto.Message):
             vulnerability.
     """
 
-    action_uri = proto.Field(proto.STRING, number=1)
-
-    fields = proto.RepeatedField(proto.STRING, number=2)
+    action_uri = proto.Field(proto.STRING, number=1,)
+    fields = proto.RepeatedField(proto.STRING, number=2,)
 
 
 class OutdatedLibrary(proto.Message):
     r"""Information reported for an outdated library.
-
     Attributes:
         library_name (str):
             The name of the outdated library.
@@ -61,11 +56,9 @@ class OutdatedLibrary(proto.Message):
             vulnerabilities in the library.
     """
 
-    library_name = proto.Field(proto.STRING, number=1)
-
-    version = proto.Field(proto.STRING, number=2)
-
-    learn_more_urls = proto.RepeatedField(proto.STRING, number=3)
+    library_name = proto.Field(proto.STRING, number=1,)
+    version = proto.Field(proto.STRING, number=2,)
+    learn_more_urls = proto.RepeatedField(proto.STRING, number=3,)
 
 
 class ViolatingResource(proto.Message):
@@ -79,25 +72,22 @@ class ViolatingResource(proto.Message):
             URL of this violating resource.
     """
 
-    content_type = proto.Field(proto.STRING, number=1)
-
-    resource_url = proto.Field(proto.STRING, number=2)
+    content_type = proto.Field(proto.STRING, number=1,)
+    resource_url = proto.Field(proto.STRING, number=2,)
 
 
 class VulnerableParameters(proto.Message):
     r"""Information about vulnerable request parameters.
-
     Attributes:
         parameter_names (Sequence[str]):
             The vulnerable parameter names.
     """
 
-    parameter_names = proto.RepeatedField(proto.STRING, number=1)
+    parameter_names = proto.RepeatedField(proto.STRING, number=1,)
 
 
 class VulnerableHeaders(proto.Message):
     r"""Information about vulnerable or missing HTTP Headers.
-
     Attributes:
         headers (Sequence[google.cloud.websecurityscanner_v1.types.VulnerableHeaders.Header]):
             List of vulnerable headers.
@@ -107,7 +97,6 @@ class VulnerableHeaders(proto.Message):
 
     class Header(proto.Message):
         r"""Describes a HTTP Header.
-
         Attributes:
             name (str):
                 Header name.
@@ -115,18 +104,15 @@ class VulnerableHeaders(proto.Message):
                 Header value.
         """
 
-        name = proto.Field(proto.STRING, number=1)
-
-        value = proto.Field(proto.STRING, number=2)
+        name = proto.Field(proto.STRING, number=1,)
+        value = proto.Field(proto.STRING, number=2,)
 
     headers = proto.RepeatedField(proto.MESSAGE, number=1, message=Header,)
-
     missing_headers = proto.RepeatedField(proto.MESSAGE, number=2, message=Header,)
 
 
 class Xss(proto.Message):
     r"""Information reported for an XSS.
-
     Attributes:
         stack_traces (Sequence[str]):
             Stack traces leading to the point where the
@@ -161,13 +147,10 @@ class Xss(proto.Message):
         SAME_ORIGIN = 14
         USER_CONTROLLABLE_URL = 15
 
-    stack_traces = proto.RepeatedField(proto.STRING, number=1)
-
-    error_message = proto.Field(proto.STRING, number=2)
-
+    stack_traces = proto.RepeatedField(proto.STRING, number=1,)
+    error_message = proto.Field(proto.STRING, number=2,)
     attack_vector = proto.Field(proto.ENUM, number=3, enum=AttackVector,)
-
-    stored_xss_seeding_url = proto.Field(proto.STRING, number=4)
+    stored_xss_seeding_url = proto.Field(proto.STRING, number=4,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
