@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,10 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
 from google.cloud.websecurityscanner_v1alpha.types import finding
 
 
@@ -39,8 +36,7 @@ class FindingTypeStats(proto.Message):
     """
 
     finding_type = proto.Field(proto.ENUM, number=1, enum=finding.Finding.FindingType,)
-
-    finding_count = proto.Field(proto.INT32, number=2)
+    finding_count = proto.Field(proto.INT32, number=2,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
