@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
 
@@ -35,9 +33,8 @@ class FindingTypeStats(proto.Message):
             finding type.
     """
 
-    finding_type = proto.Field(proto.STRING, number=1)
-
-    finding_count = proto.Field(proto.INT32, number=2)
+    finding_type = proto.Field(proto.STRING, number=1,)
+    finding_count = proto.Field(proto.INT32, number=2,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
